<?php

defined('ABSPATH') or die('Direct access not allowed.');

/* Check action input */
function mbplugins_current_action() {
  if (isset($_POST['action'])) {
    return $_POST['action'];
  }

  return false;
}

/* Sanatize and update options if set */
function mbplugins_update_options_sanatized($options) {
  foreach ($options as $key => $type) {
    if (isset($_POST[$key])) {
      if ($type == 'text_field') {
        update_option($key, sanitize_text_field($_POST[$key]));
      }
      elseif ($type == 'boolean') {
        update_option($key, filter_var($_POST[$key], FILTER_VALIDATE_BOOLEAN));
      }
      elseif ($type == 'array') {
        $sanatized = array_map('sanitize_text_field', $_POST[$key]);
        update_option($key, implode(",", $sanatized));
      }
    }
  }
}

function mbplugins_curl($path, $data = null, $auth = null, $ajax = false) {
  $url = "https://mbplugins.com/api/$path";
  $ch = curl_init();

  curl_setopt($ch, CURLOPT_URL, $url);
  curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);

  if (!empty($data)) {
    $data_string = '';
    foreach ($data as $key=>$value) {
      $data_string .= urlencode($key) . '=' . urlencode($value) . '&';
    }
    rtrim($data_string, '&');

    curl_setopt($ch, CURLOPT_POST, count($data));
    curl_setopt($ch, CURLOPT_POSTFIELDS, $data_string);
  }

  if ($auth) {
    $header = array("Authorization: Bearer $auth");
    curl_setopt($ch, CURLOPT_HTTPHEADER, $header);
  }

  $response = curl_exec($ch);
  $ch_info = curl_getinfo($ch);
  curl_close($ch);

  if ($response !== false) {
    $response = json_decode($response, true);

    if ($ch_info['http_code'] == 200 || $ch_info['http_code'] == 201 || $ch_info['http_code'] == 204) {
      return $response;
    }
    elseif ($ajax) {
      $response = array(
        "status" => $ch_info['http_code'],
        "error"  => $response['error']
      );
      return $response;
    }
    else {
      $error = (!empty($response['error'])) ? $response['error'] : 'MBPLUGINS request failed with error status <b>' . $ch_info['http_code'] . '</b>.';
      mbplugins_admin_notice($error, 'error');
      return false;
    }
  }
  elseif ($ajax) {
    $response = array(
      "status" => $ch_info['http_code'],
      "error"  => "Failed to connect to https://mbplugins.com, please try again later."
    );
    return $response;
  }
  else {
    mbplugins_admin_notice('Failed to connect to https://mbplugins.com, please try again later.', 'error');
    return false;
  }
}

/* Sort classes by start timestamp */
function mbplugins_sort_classes($a, $b) {
  if ($a['StartDateTime'] === $b['StartDateTime']) {
    return 0;
  }
  return (strtotime($a['StartDateTime']) < strtotime($b['StartDateTime'])) ? -1 : 1;
}

/* Dynamic admin notices */
function mbplugins_admin_notice($message, $type = 'info', $dismissible = true) {
  if ($message) {
    add_action('admin_notices', function() use ($message, $type, $dismissible) {
      ?>

      <div class="notice notice-<?php echo $type; if ($dismissible) echo ' is-dismissible';?>">
        <p><?php echo $message; ?></p>
      </div>

      <?php
    }, 10, 3);
  }
}

?>
